@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Georg Hennig                               *
+ *   Copyright (C) 2005-2008 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -114,7 +114,7 @@ bool KListViewItemDups::isDuplicatesPair()
 	KFileItemExt *tmp_item = item->duplicates_size;
 	int count = 1;
 	bool hasother = false;
-	while ( tmp_item ) // check whether this duplicate list contains more than two files or duplicates within one folder.
+	while ( tmp_item ) // check whether this duplicate list contains more than two files or duplicates within one directory.
 	{
 		if ( count > 2 ) break; // If there are more than two files, we surely have a duplicate that is no "brother" file.
 
