@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Georg Hennig                               *
+ *   Copyright (C) 2005-2008 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -48,7 +48,7 @@ KListViewItemSingle::KListViewItemSingle( KListView *parent, KFileItemExt *_item
 	// Fill the item with data
 	setText( 0, KIO::decodeFileName( item->url().fileName() ) );
 	setText( 1, "" ); // the directory is set individually, depending on the directory
-		// we're in (it is stripped, and only subfolders are displayed)
+		// we're in (it is stripped, and only subdirectories are displayed)
 	setText( 2, /*KGlobal::locale()->formatNumber( item->size(), 0 )*/KIO::convertSize( item->size() ) ); // Beautiful size instead of bytes
 	setText( 3, date );
 	setText( 4, item->permissionsString() );
@@ -71,7 +71,7 @@ QString KListViewItemSingle::key( int column, bool ) const
 			return QString().sprintf( "%010d", (uint)item->size() );
 		case 3:  // Returns time in secs from 1/1/1970. Used for sorting
 			return QString().sprintf( "%010ld", item->time( KIO::UDS_MODIFICATION_TIME ) );
-		case 7: // Reference folder. Don't sort by the name of it, but by the dir number.
+		case 7: // Reference directory. Don't sort by the name of it, but by the dir number.
 			return QString().sprintf( "%d", item->dir );
 	}
 	return text( column );
