@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Georg Hennig                               *
+ *   Copyright (C) 2005-2008 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -67,8 +67,8 @@ KomparatorPreset::KomparatorPreset( KomparatorWidget *_parent )
 	m_binary_comparison = false;
 	m_binary_comparison_size = 10; // in MB
 	m_duplicates_right_url_only = false;
-	m_empty_folders = false;
-	m_include_subfolders = true;
+	m_empty_directories = false;
+	m_include_subdirectories = true;
 	m_include_hidden_items = true;
 	m_use_locate = false;
 	m_case_sensitive = true;
@@ -76,7 +76,7 @@ KomparatorPreset::KomparatorPreset( KomparatorWidget *_parent )
 	m_enable_duplicates_search = true;
 	m_enable_missing_search = true;
 	m_enable_newer_search = true;
-	m_reference_folder_left = true;
+	m_reference_directory_left = true;
 
 	int i;
 	for ( i=0; i<24; i++ ) m_filter_string.push_back( "" ); // name, path, owner, group from duplicates1, 2, missing1, 2, newer1, 2.
@@ -136,7 +136,7 @@ KomparatorPreset::KomparatorPreset( KomparatorWidget *_parent )
 	m_filter_int[60] = 1;
 	m_filter_int[61] = 1;
 
-	m_virtual_subfolders.clear();
+	m_virtual_subdirectories.clear();
 }
 
 QString KomparatorPreset::title()
@@ -174,8 +174,8 @@ bool KomparatorPreset::readConfig( uint preset_number )
 	m_binary_comparison = conf->readBoolEntry( "binary_comparison" );
 	m_binary_comparison_size = conf->readUnsignedNumEntry( "binary_comparison_size" ); // in MB
 	m_duplicates_right_url_only = conf->readBoolEntry( "duplicates_right_url_only" );
-	m_empty_folders = conf->readBoolEntry( "empty_folders" );
-	m_include_subfolders = conf->readBoolEntry( "include_subfolders" );
+	m_empty_directories = conf->readBoolEntry( "empty_directories" );
+	m_include_subdirectories = conf->readBoolEntry( "include_subdirectories" );
 	m_include_hidden_items = conf->readBoolEntry( "include_hidden_items" );
 	m_use_locate = conf->readBoolEntry( "use_locate" );
 	m_case_sensitive = conf->readBoolEntry( "case_sensitive" );
@@ -183,10 +183,10 @@ bool KomparatorPreset::readConfig( uint preset_number )
 	m_enable_duplicates_search = conf->readBoolEntry( "enable_duplicates_search" );
 	m_enable_missing_search = conf->readBoolEntry( "enable_missing_search" );
 	m_enable_newer_search = conf->readBoolEntry( "enable_newer_search" );
-	m_reference_folder_left = conf->readBoolEntry( "reference_folder_left" );
+	m_reference_directory_left = conf->readBoolEntry( "reference_directory_left" );
 	m_filter_string = conf->readListEntry( "filter_string" );
 	m_filter_int = conf->readIntListEntry( "filter_int" );
-	m_virtual_subfolders = conf->readListEntry( "virtual_subfolders" );
+	m_virtual_subdirectories = conf->readListEntry( "virtual_subdirectories" );
 
 	// Sanity check for values
 	if ( m_regex_contains.isEmpty() ) m_regex_contains = "*";
@@ -225,8 +225,8 @@ bool KomparatorPreset::saveConfig( uint preset_number )
 	conf->writeEntry( "binary_comparison", m_binary_comparison );
 	conf->writeEntry( "binary_comparison_size", m_binary_comparison_size );
 	conf->writeEntry( "duplicates_right_url_only", m_duplicates_right_url_only );
-	conf->writeEntry( "empty_folders", m_empty_folders );
-	conf->writeEntry( "include_subfolders", m_include_subfolders );
+	conf->writeEntry( "empty_directories", m_empty_directories );
+	conf->writeEntry( "include_subdirectories", m_include_subdirectories );
 	conf->writeEntry( "include_hidden_items", m_include_hidden_items );
 	conf->writeEntry( "use_locate", m_use_locate );
 	conf->writeEntry( "case_sensitive", m_case_sensitive );
@@ -234,10 +234,10 @@ bool KomparatorPreset::saveConfig( uint preset_number )
 	conf->writeEntry( "enable_duplicates_search", m_enable_duplicates_search );
 	conf->writeEntry( "enable_missing_search", m_enable_missing_search );
 	conf->writeEntry( "enable_newer_search", m_enable_newer_search );
-	conf->writeEntry( "reference_folder_left", m_reference_folder_left );
+	conf->writeEntry( "reference_directory_left", m_reference_directory_left );
 	conf->writeEntry( "filter_string", m_filter_string );
 	conf->writeEntry( "filter_int", m_filter_int );
-	conf->writeEntry( "virtual_subfolders", m_virtual_subfolders );
+	conf->writeEntry( "virtual_subdirectories", m_virtual_subdirectories );
 
 	conf->sync();
 
@@ -311,8 +311,8 @@ bool KomparatorPreset::readFromInterface( bool reread )
 	m_binary_comparison = m_parent->binaryComparison_CheckBox->isChecked();
 	m_binary_comparison_size = m_parent->binaryComparison_KIntSpinBox->value(); // in MB
 	m_duplicates_right_url_only = m_parent->duplicatesOnly_CheckBox->isChecked();
-	m_empty_folders = m_parent->findEmptyFolders_CheckBox->isChecked();
-	m_include_subfolders = m_parent->includeSubfolders_CheckBox->isChecked();
+	m_empty_directories = m_parent->findEmptyDirectories_CheckBox->isChecked();
+	m_include_subdirectories = m_parent->includeSubdirectories_CheckBox->isChecked();
 	m_include_hidden_items = m_parent->includeHiddenItems_CheckBox->isChecked();
 	m_use_locate = m_parent->useFilesIndex_CheckBox->isChecked();
 	m_case_sensitive = m_parent->caseSensitiveSearch_CheckBox->isChecked();
@@ -320,7 +320,7 @@ bool KomparatorPreset::readFromInterface( bool reread )
 	m_enable_duplicates_search = m_parent->isEnabled( DUPLICATES );
 	m_enable_missing_search = m_parent->isEnabled( MISSING );
 	m_enable_newer_search = m_parent->isEnabled( NEWER );
-	m_reference_folder_left = m_parent->duplicatesReference1_RadioButton->isChecked();
+	m_reference_directory_left = m_parent->duplicatesReference1_RadioButton->isChecked();
 
 	QStringList string_list;
 	string_list = m_parent->duplicates1_KomparatorFileFilter->getStringList() + m_parent->duplicates2_KomparatorFileFilter->getStringList() +
@@ -335,12 +335,12 @@ bool KomparatorPreset::readFromInterface( bool reread )
 		m_parent->newer1_KomparatorFileFilter->getIntList() + m_parent->newer2_KomparatorFileFilter->getIntList();
 	m_filter_int = int_list;
 
-	KURL::List virtual_subfolders = m_parent->subfolders_KomparatorUrlList->getUrlList();
-	m_virtual_subfolders.clear();
+	KURL::List virtual_subdirectories = m_parent->subdirectories_KomparatorUrlList->getUrlList();
+	m_virtual_subdirectories.clear();
 	KURL::List::Iterator it;
-	for ( it=virtual_subfolders.begin(); it != virtual_subfolders.end(); ++it )
+	for ( it=virtual_subdirectories.begin(); it != virtual_subdirectories.end(); ++it )
 	{
-		m_virtual_subfolders.push_back( (*it).url() );
+		m_virtual_subdirectories.push_back( (*it).url() );
 	}
 
 	return true;
@@ -369,8 +369,8 @@ void KomparatorPreset::setToInterface()
 	m_parent->binaryComparison_CheckBox->setChecked( m_binary_comparison );
 	m_parent->binaryComparison_KIntSpinBox->setValue( m_binary_comparison_size );
 	m_parent->duplicatesOnly_CheckBox->setChecked( m_duplicates_right_url_only );
-	m_parent->findEmptyFolders_CheckBox->setChecked( m_empty_folders );
-	m_parent->includeSubfolders_CheckBox->setChecked( m_include_subfolders );
+	m_parent->findEmptyDirectories_CheckBox->setChecked( m_empty_directories );
+	m_parent->includeSubdirectories_CheckBox->setChecked( m_include_subdirectories );
 	m_parent->includeHiddenItems_CheckBox->setChecked( m_include_hidden_items );
 	m_parent->useFilesIndex_CheckBox->setChecked( m_use_locate );
 	m_parent->caseSensitiveSearch_CheckBox->setChecked( m_case_sensitive );
@@ -381,8 +381,8 @@ void KomparatorPreset::setToInterface()
 		KGlobal::iconLoader()->loadIconSet( m_enable_missing_search ? "ok" : "no", KIcon::Toolbar, KIcon::SizeSmall ) );
 	m_parent->main_TabWidget->setTabIconSet( m_parent->main_TabWidget->page( 2 ),
 		KGlobal::iconLoader()->loadIconSet( m_enable_newer_search ? "ok" : "no", KIcon::Toolbar, KIcon::SizeSmall ) );
-	m_parent->duplicatesReference1_RadioButton->setChecked( m_reference_folder_left );
-	m_parent->duplicatesReference2_RadioButton->setChecked( !m_reference_folder_left );
+	m_parent->duplicatesReference1_RadioButton->setChecked( m_reference_directory_left );
+	m_parent->duplicatesReference2_RadioButton->setChecked( !m_reference_directory_left );
 
 	if ( m_filter_string.size() == 25 && m_filter_string[24] == "EOL" )
 	{
@@ -436,10 +436,10 @@ void KomparatorPreset::setToInterface()
 		m_parent->newer2_KomparatorFileFilter->setIntList( int_list );
 	}
 
-	m_parent->subfolders_KomparatorUrlList->clear();
+	m_parent->subdirectories_KomparatorUrlList->clear();
 	QStringList::Iterator it;
-	for ( it=m_virtual_subfolders.begin(); it!=m_virtual_subfolders.end(); ++it )
+	for ( it=m_virtual_subdirectories.begin(); it!=m_virtual_subdirectories.end(); ++it )
 	{
-		m_parent->subfolders_KomparatorUrlList->addUrl( KURL( *it ) );
+		m_parent->subdirectories_KomparatorUrlList->addUrl( KURL( *it ) );
 	}
 }
