@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Georg Hennig                               *
+ *   Copyright (C) 2005-2008 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -62,8 +62,8 @@ class KomparatorPreset
 		bool m_binary_comparison;
 		uint m_binary_comparison_size; // in MB
 		bool m_duplicates_right_url_only;
-		bool m_empty_folders;
-		bool m_include_subfolders;
+		bool m_empty_directories;
+		bool m_include_subdirectories;
 		bool m_include_hidden_items;
 		bool m_use_locate;
 		bool m_case_sensitive;
@@ -71,10 +71,10 @@ class KomparatorPreset
 		bool m_enable_duplicates_search;
 		bool m_enable_missing_search;
 		bool m_enable_newer_search;
-		bool m_reference_folder_left;
+		bool m_reference_directory_left;
 		QStringList m_filter_string;
 		QValueList<int> m_filter_int;
-		QStringList m_virtual_subfolders;
+		QStringList m_virtual_subdirectories;
 };
 
 #endif
