@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Georg Hennig                               *
+ *   Copyright (C) 2005-2008 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,6 +27,10 @@
 #include "komparatorwidgetbase.h"
 
 class KomparatorCompareJob;
+class KomparatorEmptyDirectoryJob;
+class KomparatorCopyJob;
+class KomparatorMoveJob;
+class KomparatorRemoveJob;
 class KFileItem;
 class KFileItemExt;
 class KListViewItemDups;
@@ -40,6 +44,7 @@ enum STATUS
 	CLEAN = 0,
 	SEARCHING_URL_1,
 	SEARCHING_URL_2,
+	SEARCHING_EMPTY_DIRECTORIES,
 	COMPARING,
 	READY,
 	INTERACTING
@@ -108,7 +113,7 @@ class KomparatorWidget : public KomparatorWidgetBase
 		virtual void slotRemoveFromList();
 		virtual void slotOpenBinding();
 		virtual void slotExecute( QListViewItem *item );
-		virtual void slotOpenFolder();
+		virtual void slotOpenDirectory();
 		virtual void slotCopySelection();
 		virtual void slotTrashFiles();
 		virtual void slotDeleteFiles();
@@ -179,8 +184,6 @@ class KomparatorWidget : public KomparatorWidgetBase
 		virtual void slotMD5ChecksumEnabled( bool e );
 		virtual void slotDuplicatesOnlyEnabled( bool e );
 		virtual void slotSizeEnabled( bool e );
-		virtual void slotEmptyFolder( KIO::Job *job, const KIO::UDSEntryList &list );
-		virtual void slotEmptyFolderFinished( KIO::Job *job );
 		virtual void slotProgress( QString str, int percent, QString notification );
 		virtual void slotProgressUndefined();
 		virtual void slotSaveListViewColumnWidth();
@@ -204,8 +207,13 @@ class KomparatorWidget : public KomparatorWidgetBase
 		KURL m_url2;
 
 		KURL::List m_symlinked_directories;
-		KURL::List m_virtual_subfolders;
-		KURL m_virtual_subfolder_current;
+		KURL::List m_virtual_subdirectories;
+		KURL m_virtual_subdirectory_current;
+
+		KomparatorEmptyDirectoryJob *m_empty_directory_job;
+		KomparatorCopyJob *m_copy_job;
+		KomparatorMoveJob *m_move_job;
+		KomparatorRemoveJob *m_remove_job;
 
 		KPopupMenu *m_popup_menu;
 
